package com.example.smartledz_wifi_test.plugin;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.EventChannel;

public class EventChannelPlugin implements FlutterPlugin, EventChannel.StreamHandler{

    public static final String CHANNEL_NAME = "native_event_channel";
    private EventChannel eventChannel;
    private EventChannel.EventSink eventSink;

    private static volatile EventChannelPlugin instance;

    private EventChannelPlugin() {
    }

    public static EventChannelPlugin getInstance() {
        if (instance == null) {
            synchronized (EventChannelPlugin.class) {
                if (instance == null) {
                    instance = new EventChannelPlugin();
                }
            }
        }
        return instance;
    }

    /**
     * 处理设置事件流的请求。
     *
     * @param arguments 流配置参数，可能为空。
     * @param events    用于向flutter接收器发射事件。
     */
    @Override
    public void onListen(Object arguments, EventChannel.EventSink events) {
        this.eventSink = events;
    }

    /**
     * 处理请求以删除最近创建的事件流。
     *
     * @param arguments 流配置参数，可能为空。
     */
    @Override
    public void onCancel(Object arguments) {

    }

    public void sendEventData(Object data) {
//        System.out.printf("通知数据:"+data.toString());
        if (eventSink != null) {
            eventSink.success(data);
        }
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        eventChannel = new EventChannel(binding.getBinaryMessenger(), CHANNEL_NAME);
        eventChannel.setStreamHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        eventSink.endOfStream();
        eventChannel.setStreamHandler(null);
    }
}
